import type { Metadata, Viewport } from 'next';
import { Inter } from 'next/font/google'; // Use Inter for a clean look
import './globals.css';
import { Toaster } from "@/components/ui/toaster"; // Import Toaster
import { cn } from '@/lib/utils'; // Import cn utility
import { ThemeProvider } from "@/components/theme-provider"; // Import ThemeProvider
import { Navbar } from '@/components/navbar'; // Import Navbar
import { AuthProvider } from '@/contexts/auth-context'; // Import AuthProvider
import { LanguageProvider } from '@/contexts/language-context'; // Import LanguageProvider

const inter = Inter({ subsets: ['latin'], variable: '--font-sans' }); // Configure Inter font

// Metadata without viewport
export const metadata: Metadata = {
  title: 'Psonio - Grocery Checklist', // Changed from ShopMaster to Psonio
  description: 'Manage your grocery lists across multiple stores.', // Update description
};

// Separate viewport export
export const viewport: Viewport = {
  width: 'device-width',
  initialScale: 1,
  maximumScale: 1,
};

export default function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) {
  return (
    <html lang="en" suppressHydrationWarning>
      <body className={cn(inter.variable, 'font-sans antialiased')}>
        <AuthProvider> {/* Wrap with AuthProvider */}
          <LanguageProvider> {/* Wrap with LanguageProvider */}
            <ThemeProvider
              attribute="class"
              defaultTheme="system"
              enableSystem
              disableTransitionOnChange
            >
              <div className="relative flex min-h-screen flex-col">
                <Navbar /> {/* Add Navbar here */}
                <main className="flex-1">{children}</main> {/* Wrap children in main */}
              </div>
              <Toaster />
            </ThemeProvider>
          </LanguageProvider>
        </AuthProvider>
      </body>
    </html>
  );
}
